<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml" indent="yes" omit-xml-declaration="yes"/>
<xsl:strip-space elements="*"/>

<xsl:template match="*">
	<xsl:copy>
		<xsl:copy-of select="@*"/>
		<xsl:apply-templates/>
	</xsl:copy>
</xsl:template>

<xsl:template match="//hml/xtt/table/schm" >
	<xsl:copy> <xsl:apply-templates/> </xsl:copy>
</xsl:template>

<xsl:template match="//hml/xtt/table/rule/condition/relation">
  <xsl:variable name="stringFromSet">
  	<!--  <xsl:text>[</xsl:text> -->
	<xsl:call-template name="setToString">
		<xsl:with-param name="rel" select="@name"/>
		<xsl:with-param name="set" select="./set"/>
	</xsl:call-template>
	<!-- <xsl:text>]</xsl:text> -->
  </xsl:variable>

  <xsl:element name="relation">
	<xsl:attribute name="attRef"><xsl:value-of select="attref/@ref"/></xsl:attribute>
	<xsl:attribute name="attName"><xsl:value-of select="//hml/attributes/attr[@id=current()/attref/@ref]/@name"/></xsl:attribute>
	<xsl:attribute name="relName"><xsl:value-of select="@name"/></xsl:attribute>
	<xsl:value-of select="$stringFromSet"/>
  </xsl:element>
</xsl:template>

<xsl:template match="//hml/xtt/table/rule/decision/trans">
	<xsl:variable name="stringFromSetOrExpr">
	<xsl:choose>
		<xsl:when test="set">			
			<xsl:call-template name="setToString">
				<xsl:with-param name="set" select="./set"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="expr">
		  	<xsl:call-template name="exprToString">
		  		<xsl:with-param name="expr" select="current()/expr"/>
		  		<xsl:with-param name="name" select="current()/expr/@name"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="count(attref)=2"><!-- przypisujemy wartosc atrybutu -->			
			<xsl:value-of select="//hml/attributes/attr[@id=current()/attref[2]/@ref]/@name"/>
		</xsl:when>
	</xsl:choose>
	</xsl:variable>		
	
	<xsl:element name="trans">
		<xsl:attribute name="attRef"><xsl:value-of select="attref/@ref"/></xsl:attribute>
		<xsl:attribute name="attName"><xsl:value-of select="//hml/attributes/attr[@id=current()/attref/@ref]/@name"/></xsl:attribute>
		<xsl:value-of select="$stringFromSetOrExpr"/>
	</xsl:element>
</xsl:template>

<!-- returns string from the set of values -->
<xsl:template name="setToString"> 
	<xsl:param name="att"/>
	<xsl:param name="set"/>
	<xsl:param name="rel"/>
	<xsl:param name="res" select="1"/>
	
	<xsl:choose>
	  <xsl:when test="$rel='eq'"><!--<xsl:text>= </xsl:text>--></xsl:when>
	  <xsl:when test="$rel='neq'"><xsl:text>!= </xsl:text></xsl:when>
	  <xsl:when test="$rel='in'"><xsl:text>in </xsl:text></xsl:when>
	  <xsl:when test="$rel='notin'"><xsl:text>notIn </xsl:text></xsl:when>
	  <xsl:when test="$rel='lt'"><xsl:text>&lt; </xsl:text></xsl:when>
	  <xsl:when test="$rel='lte'"><xsl:text>&lt;= </xsl:text></xsl:when>
	  <xsl:when test="$rel='gt'"><xsl:text>&gt;= </xsl:text></xsl:when>
	  <xsl:when test="$rel='gte'"><xsl:text>&gt; </xsl:text></xsl:when>
	  <xsl:when test="$rel='sim'"><xsl:text>sim </xsl:text></xsl:when>
	  <xsl:when test="$rel='notsim'"><xsl:text>notSim </xsl:text></xsl:when>
	  <xsl:when test="$rel='subseteq'"><xsl:text>subsetOf </xsl:text></xsl:when>
	  <xsl:when test="$rel='supseteq'"><xsl:text>supsetOf </xsl:text></xsl:when>
	  <xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
	</xsl:choose>
	<xsl:if test="count($set/value)>1"><xsl:text>{</xsl:text></xsl:if>
	<xsl:for-each select="$set/value">
		<xsl:if test="@*[name(.)='is']"> <!-- for the one value -->
			<xsl:value-of select="@is"/>
			<xsl:if test="not(position() = last())"><xsl:text>; </xsl:text></xsl:if>
		</xsl:if>
		<xsl:if test="@*[name(.)='from']"> <!-- for the range of values -->
			<xsl:text>[</xsl:text><!-- &lt; -->
			<xsl:value-of select="@from"/>
			<xsl:text>, </xsl:text>
			<xsl:value-of select="@to"/>
			<xsl:text>]</xsl:text><!-- &gt; -->
		</xsl:if>
	</xsl:for-each>
	<xsl:if test="count($set/value)>1"><xsl:text>}</xsl:text></xsl:if>
</xsl:template>


<!-- returns string from the expression -->
<xsl:template name="exprToString"> 
	<xsl:param name="name"/>
	<xsl:param name="expr"/>
	<xsl:param name="rel"/>
	<xsl:param name="res" select="1"/>

	<xsl:value-of select="$name"/> <xsl:text>(</xsl:text> 
	<xsl:for-each select="$expr/child::node()">
		<xsl:variable name="nodeName">
				<xsl:value-of select="local-name()"/>
		</xsl:variable>		
		<xsl:choose>	
			<xsl:when test="$nodeName='attref'">
				<xsl:value-of select="//hml/attributes/attr[@id=current()/@ref]/@name"/>
			</xsl:when>
			<xsl:when test="$nodeName='value'">
				<xsl:if test="@*[name(.)='is']"> <!-- for the one value -->
					<xsl:value-of select="@is"/>					
				</xsl:if>
				<xsl:if test="@*[name(.)='from']"> <!-- for the range of values -->
					<xsl:text>[</xsl:text><!-- &lt; -->
					<xsl:value-of select="@from"/>
					<xsl:text>, </xsl:text>
					<xsl:value-of select="@to"/>
					<xsl:text>]</xsl:text><!-- &gt; -->
				</xsl:if>
			</xsl:when>
			<xsl:when test="$nodeName='expr'">
				<xsl:call-template name="exprToString">
					<xsl:with-param name="expr" select="current()"/>
					<xsl:with-param name="name" select="current()/@name"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
		</xsl:choose>
		<xsl:if test="not(position() = last())"><xsl:text>, </xsl:text></xsl:if>		
	</xsl:for-each>
	<xsl:text>)</xsl:text>
</xsl:template> 
	
</xsl:stylesheet>
